==> django-activity-stream-0.6.0.tar.gz: django-activity-stream-0.6.0/setup.py <==
from distutils.core import setup
from actstream import __version__

setup(name='django-activity-stream',
      version=__version__,
      description='Generate generic activity streams from the actions on your '
      'site. Users can follow any actor\'s activities for personalized streams.',
      long_description=open('README.rst').read(),
      author='Justin Quick',
      author_email='justquick@gmail.com',
      url='http://github.com/justquick/django-activity-stream',
      packages=['actstream',
                'actstream.migrations',
                'actstream.south_migrations',
                'actstream.templatetags',
                'actstream.tests',
                'actstream.runtests',
                'actstream.runtests.testapp',
                'actstream.runtests.testapp.migrations',
                'actstream.runtests.testapp.south_migrations',
                'actstream.runtests.testapp_nested',
                'actstream.runtests.testapp_nested.migrations',
                'actstream.runtests.testapp_nested.south_migrations',
                'actstream.runtests.testapp_nested.models',
      ],
      package_data={'actstream': ['locale/*/LC_MESSAGES/*.po',
                                  'templates/actstream/*.html']},
      zip_safe=False,
      classifiers=['Development Status :: 5 - Production/Stable',
                   'Environment :: Web Environment',
                   'Framework :: Django',
                   'Intended Audience :: Developers',
                   'License :: OSI Approved :: BSD License',
                   'Operating System :: OS Independent',
                   'Programming Language :: Python',
                   'Programming Language :: Python :: 3',
                   'Topic :: Utilities'],
      )

==> django-activity-stream-0.6.3.tar.gz: django-activity-stream-0.6.3/setup.py <==
from distutils.core import setup
from actstream import __version__

setup(name='django-activity-stream',
      version=__version__,
      description='Generate generic activity streams from the actions on your '
      'site. Users can follow any actors\' activities for personalized streams.',
      long_description=open('README.rst').read(),
      author='Justin Quick',
      author_email='justquick@gmail.com',
      url='http://github.com/justquick/django-activity-stream',
      packages=['actstream',
                'actstream.migrations',
                'actstream.south_migrations',
                'actstream.templatetags',
                'actstream.tests',
                'actstream.runtests',
                'actstream.runtests.testapp',
                'actstream.runtests.testapp.migrations',
                'actstream.runtests.testapp.south_migrations',
                'actstream.runtests.testapp_nested',
                'actstream.runtests.testapp_nested.migrations',
                'actstream.runtests.testapp_nested.south_migrations',
                'actstream.runtests.testapp_nested.models',
      ],
      package_data={'actstream': ['locale/*/LC_MESSAGES/*.po',
                                  'templates/actstream/*.html']},
      classifiers=['Development Status :: 5 - Production/Stable',
                   'Environment :: Web Environment',
                   'Framework :: Django',
                   'Intended Audience :: Developers',
                   'License :: OSI Approved :: BSD License',
                   'Operating System :: OS Independent',
                   'Programming Language :: Python',
                   'Programming Language :: Python :: 3',
                   'Topic :: Utilities'],
      )
